aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--lib/VMCore/Module.cpp18
1 files changed, 11 insertions, 7 deletions
diff --git a/lib/VMCore/Module.cpp b/lib/VMCore/Module.cpp
index 836ed47..990774a 100644
--- a/lib/VMCore/Module.cpp
+++ b/lib/VMCore/Module.cpp
@@ -61,6 +61,11 @@ Module::~Module() {
delete SymTab;
}
+// Module::dump() - Allow printing from debugger
+void Module::dump() const {
+ print(std::cerr);
+}
+
SymbolTable *Module::getSymbolTableSure() {
if (!SymTab) SymTab = new SymbolTable(0);
return SymTab;
@@ -147,13 +152,12 @@ std::string Module::getTypeName(const Type *Ty) {
}
// dropAllReferences() - This function causes all the subinstructions to "let
// go" of all references that they are maintaining. This allows one to
// 'delete' a whole class at a time, even though there may be circular
// references... first all references are dropped, and all use counts go to
// zero. Then everything is delete'd for real. Note that no operations are
// valid on an object that has "dropped all references", except operator
// delete.
//
void Module::dropAllReferences() {
for(Module::iterator I = begin(), E = end(); I != E; ++I)
@@ -147,13 +152,12 @@ std::string Module::getTypeName(const Type *Ty) {
}
-// dropAllReferences() - This function causes all the subinstructions to "let
-// go" of all references that they are maintaining. This allows one to
-// 'delete' a whole class at a time, even though there may be circular
-// references... first all references are dropped, and all use counts go to
-// zero. Then everything is delete'd for real. Note that no operations are
-// valid on an object that has "dropped all references", except operator
-// delete.
+// dropAllReferences() - This function causes all the subelementss to "let go"
+// of all references that they are maintaining. This allows one to 'delete' a
+// whole module at a time, even though there may be circular references... first
+// all references are dropped, and all use counts go to zero. Then everything
+// is delete'd for real. Note that no operations are valid on an object that
+// has "dropped all references", except operator delete.
//
void Module::dropAllReferences() {